@@ -2,7 +2,7 @@
   This file is part of Kontact.
 
   Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
-  Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@
 #include <KontactInterface/Plugin>
 
 #include <KMime/Message>
-
 #include <KCheckableProxyModel>
 #include <KIconEffect>
 #include <KIconLoader>
@@ -189,12 +188,13 @@ void KNotesSummaryWidget::createNote(const Akonadi::Item &item, int counter)
     urlLabel->installEventFilter(this);
     urlLabel->setAlignment(Qt::AlignLeft);
     urlLabel->setWordWrap(true);
-    connect(urlLabel, qOverload<const QString &>(&KUrlLabel::leftClickedUrl),
-            this, &KNotesSummaryWidget::slotSelectNote);
-
-    connect(urlLabel, qOverload<const QString &>(&KUrlLabel::rightClickedUrl),
-            this, &KNotesSummaryWidget::slotPopupMenu);
+    connect(urlLabel, &KUrlLabel::leftClickedUrl, this, [this, urlLabel]() {
+        slotSelectNote(urlLabel->url()); }
+    );
 
+    connect(urlLabel, &KUrlLabel::rightClickedUrl, this, [this, urlLabel]() {
+        slotPopupMenu(urlLabel->url()); }
+    );
     mLayout->addWidget(urlLabel, counter, 1);
 
     QColor color;
